@@ -12,8 +12,7 @@
 
 from gi.repository import GLib
 
-from lollypop.helper_art import ArtHelperEffect
-from lollypop.define import Type, App
+from lollypop.define import Type, App, ArtHelperEffect
 
 
 class InformationController:
@@ -29,7 +28,7 @@ class InformationController:
         """
         self._infobox = None
         self.__effect = effect
-        self.__previous_artwork_id = None
+        self._previous_artwork_id = None
         self.__show_tooltip = show_tooltip
         self.__per_track_cover = App().settings.get_value(
             "allow-per-track-cover")
@@ -83,18 +82,18 @@ class InformationController:
             @param width as int
             @param height as int
         """
-        same_artwork = self.__previous_artwork_id ==\
+        same_artwork = self._previous_artwork_id ==\
             App().player.current_track.album.id
         if width < 1 or height < 1 or same_artwork:
             return
-        self.__previous_artwork_id = App().player.current_track.album.id
+        self._previous_artwork_id = App().player.current_track.album.id
         if App().player.current_track.id == Type.RADIOS:
             App().art_helper.set_radio_artwork(
                 App().player.current_track.radio_name,
                 width,
                 height,
                 self._artwork.get_scale_factor(),
-                self.__on_radio_artwork,
+                self._on_artwork,
                 self.__effect)
         elif App().player.current_track.id is not None:
             App().art_helper.set_album_artwork(
@@ -102,42 +101,18 @@ class InformationController:
                 width,
                 height,
                 self._artwork.get_scale_factor(),
-                self.__on_album_artwork,
+                self._on_artwork,
                 self.__effect)
             if self.__show_tooltip:
                 self._artwork.set_tooltip_text(
                     App().player.current_track.album.name)
 
-    def set_art_size(self, art_size):
-        """
-            Set a new art_size for controller
-            @param art_size as int
-        """
-        self.__art_size = art_size
-
-    @property
-    def art_size(self):
-        """
-            Art size as int
-        """
-        return self.__art_size
-
-#######################
-# PRIVATE             #
-#######################
-    def __on_album_artwork(self, surface):
+    def _on_artwork(self, surface):
         """
             Set album artwork
             @param surface as str
         """
         self._artwork.set_from_surface(surface)
-
-    def __on_radio_artwork(self, surface):
-        """
-            Set radio artwork
-            @param surface as str
-        """
-        if surface is None:
-            self._artwork.hide()
-        else:
-            self._artwork.set_from_surface(surface)
+#######################
+# PRIVATE             #
+#######################
