@@ -35,7 +35,8 @@ class ProgressController:
             Update scale on current changed
             @param player as Player
         """
-        self._progress.clear_marks()
+        style_context = self._progress.get_style_context()
+        style_context.remove_class("youtube-scale")
         if player.current_track.id is None:
             self._progress.set_sensitive(False)
             self._total_time_label.set_text("")
@@ -46,14 +47,32 @@ class ProgressController:
         self._timelabel.set_text("0:00")
         if player.current_track.id == Type.RADIOS:
             self._progress.set_sensitive(False)
-            self._total_time_label.set_text("")
+            self._progress.set_opacity(0)
+            self._timelabel.set_opacity(0)
+            self._total_time_label.set_opacity(0)
             self._progress.set_range(0.0, 0.0)
         else:
+            if player.current_track.mtime <= 0:
+                style_context.add_class("youtube-scale")
             self._progress.set_sensitive(True)
+            self._progress.set_opacity(1)
+            self._timelabel.set_opacity(1)
+            self._total_time_label.set_opacity(1)
             self._progress.set_range(0.0, player.current_track.duration)
             self._total_time_label.set_text(
                 seconds_to_string(player.current_track.duration))
 
+    def on_duration_changed(self, player, track_id):
+        """
+            Update duration
+            @param player as Player
+            @param track_id as int
+        """
+        if track_id == player.current_track.id:
+            duration = player.current_track.duration
+            self._progress.set_range(0.0, duration)
+            self._total_time_label.set_text(seconds_to_string(duration))
+
     def on_status_changed(self, player):
         """
             Update buttons and progress bar
@@ -64,7 +83,6 @@ class ProgressController:
                 self.__timeout_id = GLib.timeout_add(1000,
                                                      self.update_position)
         else:
-            self.update_position()
             if self.__timeout_id is not None:
                 GLib.source_remove(self.__timeout_id)
                 self.__timeout_id = None
@@ -77,7 +95,7 @@ class ProgressController:
         if not self.__seeking:
             if value is None and App().player.get_status() != Gst.State.PAUSED:
                 value = App().player.position / Gst.SECOND
-            if value is not None:
+            if value is not None and value >= 0:
                 self._progress.set_value(value)
                 self._timelabel.set_text(seconds_to_string(value))
         return True
@@ -112,8 +130,6 @@ class ProgressController:
             @param scale as Gtk.Scale
             @param event as Gdk.Event
         """
-        if App().player.is_locked:
-            return True
         self.__seeking = True
 
     def _on_progress_release_button(self, scale, event):
