@@ -150,7 +150,8 @@ class DatabaseAlbumsUpgrade(DatabaseUpgrade):
             28: self.__upgrade_28,
             29: self.__upgrade_29,
             30: "ALTER TABLE tracks ADD loved INT NOT NULL DEFAULT 0",
-            31: self.__upgrade_31
+            31: self.__upgrade_31,
+            32: "ALTER TABLE tracks ADD bpm DOUBLE"
         }
 
 #######################
