@@ -19,7 +19,7 @@ from gi.repository import Gio, Gst, GLib, Gtk
 from random import randint
 
 from lollypop.logger import Logger
-from lollypop.define import App, ArtSize, Type, Shuffle, NextContext
+from lollypop.define import App, ArtSize, Type, Shuffle, Repeat
 from lollypop.objects import Track
 
 
@@ -199,7 +199,7 @@ class MPRIS(Server):
         App().player.connect("volume-changed", self.__on_volume_changed)
         App().player.connect("rate-changed", self.__on_rate_changed)
         App().settings.connect("changed::shuffle", self.__on_shuffle_changed)
-        App().settings.connect("changed::playback", self.__on_playback_changed)
+        App().settings.connect("changed::repeat", self.__on_repeat_changed)
 
     def Raise(self):
         self.__app.window.setup()
@@ -285,10 +285,10 @@ class MPRIS(Server):
         elif property_name == "PlaybackStatus":
             return GLib.Variant("s", self.__get_status())
         elif property_name == "LoopStatus":
-            repeat = App().settings.get_enum("playback")
-            if repeat == NextContext.NONE:
+            repeat = App().settings.get_enum("repeat")
+            if repeat == Repeat.ALL:
                 value = "Playlist"
-            elif repeat == NextContext.REPEAT_TRACK:
+            elif repeat == Repeat.TRACK:
                 value = "Track"
             else:
                 value = "None"
@@ -347,12 +347,12 @@ class MPRIS(Server):
                 App().settings.set_enum("shuffle", Shuffle.NONE)
         elif property_name == "LoopStatus":
             if new_value == "Playlist":
-                value = NextContext.NONE
+                value = Repeat.ALL
             elif new_value == "Track":
-                value = NextContext.REPEAT_TRACK
+                value = Repeat.TRACK
             else:
-                value = NextContext.STOP
-            App().settings.set_enum("playback", value)
+                value = Repeat.NONE
+            App().settings.set_enum("repeat", value)
 
     def PropertiesChanged(self, interface_name, changed_properties,
                           invalidated_properties):
@@ -397,34 +397,48 @@ class MPRIS(Server):
                 "/org/mpris/MediaPlayer2/TrackList/NoTrack")}
         else:
             self.__metadata["mpris:trackid"] = self.__track_id
-            track_number = App().player.current_track.number
-            if track_number is None:
-                track_number = 1
-            self.__metadata["xesam:trackNumber"] = GLib.Variant("i",
-                                                                track_number)
-            self.__metadata["xesam:title"] = GLib.Variant(
-                "s",
-                App().player.current_track.name)
-            self.__metadata["xesam:album"] = GLib.Variant(
-                "s",
-                App().player.current_track.album.name)
-            self.__metadata["xesam:artist"] = GLib.Variant(
-                "as",
-                App().player.current_track.artists)
-            self.__metadata["xesam:albumArtist"] = GLib.Variant(
-                "as",
-                App().player.current_track.album_artists)
-            self.__metadata["mpris:length"] = GLib.Variant(
-                "x",
-                App().player.current_track.duration * 1000 * 1000)
-            self.__metadata["xesam:genre"] = GLib.Variant(
-                "as",
-                App().player.current_track.genres)
+            if App().player.current_track.id == Type.RADIOS:
+                self.__metadata["xesam:title"] = GLib.Variant(
+                    "s",
+                    App().player.current_track.name)
+                self.__metadata["xesam:artist"] = GLib.Variant(
+                    "as",
+                    [App().player.current_track.radio_name])
+                self.__metadata["xesam:trackNumber"] = GLib.Variant(
+                    "i", 0)
+                self.__metadata["xesam:album"] = GLib.Variant("s", "")
+                self.__metadata["xesam:albumArtist"] = GLib.Variant("as",  [])
+                self.__metadata["mpris:length"] = GLib.Variant("x", 0)
+                self.__metadata["xesam:genre"] = GLib.Variant("as", [])
+            else:
+                track_number = App().player.current_track.number
+                if track_number is None:
+                    track_number = 1
+                self.__metadata["xesam:trackNumber"] = GLib.Variant(
+                    "i",
+                    track_number)
+                self.__metadata["xesam:title"] = GLib.Variant(
+                    "s",
+                    App().player.current_track.name)
+                self.__metadata["xesam:album"] = GLib.Variant(
+                    "s",
+                    App().player.current_track.album.name)
+                self.__metadata["xesam:artist"] = GLib.Variant(
+                    "as",
+                    App().player.current_track.artists)
+                self.__metadata["xesam:albumArtist"] = GLib.Variant(
+                    "as",
+                    App().player.current_track.album_artists)
+                self.__metadata["mpris:length"] = GLib.Variant(
+                    "x",
+                    App().player.current_track.duration * 1000 * 1000)
+                self.__metadata["xesam:genre"] = GLib.Variant(
+                    "as",
+                    App().player.current_track.genres)
             self.__metadata["xesam:url"] = GLib.Variant(
                 "s",
                 App().player.current_track.uri)
-            if self.__rating is None:
-                self.__rating = App().player.current_track.get_rate()
+            self.__rating = App().player.current_track.get_rate()
             self.__metadata["xesam:userRating"] = GLib.Variant(
                 "d",
                 self.__rating / 5)
@@ -436,10 +450,11 @@ class MPRIS(Server):
                 cover_path = App().art.get_album_cache_path(
                     App().player.current_track.album,
                     ArtSize.MONSTER, ArtSize.MONSTER)
-            if cover_path is not None:
-                self.__metadata["mpris:artUrl"] = GLib.Variant(
-                    "s",
-                    "file://" + cover_path)
+            if cover_path is None:
+                cover_path = ""
+            self.__metadata["mpris:artUrl"] = GLib.Variant(
+                "s",
+                "file://" + cover_path)
 
     def __on_seeked(self, player, position):
         self.Seeked(position * (1000 * 1000))
@@ -461,32 +476,32 @@ class MPRIS(Server):
         properties = {"Shuffle": GLib.Variant("b", value)}
         self.PropertiesChanged(self.__MPRIS_PLAYER_IFACE, properties, [])
 
-    def __on_playback_changed(self, settings, value):
-        value = App().settings.get_enum("playback")
-        if value == NextContext.NONE:
-            mpris_value = "Playlist"
-        elif value == NextContext.REPEAT_TRACK:
-            mpris_value = "Track"
+    def __on_repeat_changed(self, settings, value):
+        repeat = App().settings.get_enum("repeat")
+        if repeat == Repeat.ALL:
+            value = "Playlist"
+        elif repeat == Repeat.TRACK:
+            value = "Track"
         else:
-            mpris_value = "None"
-        properties = {"LoopStatus": GLib.Variant("s", mpris_value)}
+            value = "None"
+        properties = {"LoopStatus": GLib.Variant("s", value)}
         self.PropertiesChanged(self.__MPRIS_PLAYER_IFACE, properties, [])
 
-    def __on_rate_changed(self, player, id_rating):
-        rated_track_id, rating = id_rating
+    def __on_rate_changed(self, player, rated_track_id, rating):
         # We only care about the current Track's rating.
-        if rated_track_id == self.__lollypop_id and self.__rating != rating:
+        if rated_track_id == self.__lollypop_id:
             self.__rating = rating
             self.__update_metadata()
             properties = {"Metadata": GLib.Variant("a{sv}", self.__metadata)}
             self.PropertiesChanged(self.__MPRIS_PLAYER_IFACE, properties, [])
 
     def __on_current_changed(self, player):
-        current_track_id = App().player.current_track.id
-        if current_track_id and current_track_id >= 0:
-            self.__lollypop_id = current_track_id
-        else:
+        if App().player.current_track.id is None:
             self.__lollypop_id = 0
+        elif App().player.current_track.id == Type.RADIOS:
+            self.__lollypop_id = App().player.current_track.radio_id
+        else:
+            self.__lollypop_id = App().player.current_track.id
         # We only need to recalculate a new trackId at song changes.
         self.__track_id = self.__get_media_id(self.__lollypop_id)
         self.__rating = None
