@@ -331,19 +331,17 @@ class BinPlayer(BasePlayer):
         reader = TagReader()
         tags = message.parse_tag()
         title = reader.get_title(tags, "")
-        if title != "" and self._current_track.name != title:
+        if len(title) > 1 and self._current_track.name != title:
             self._current_track.name = title
             changed = True
-        if self._current_track.name == "":
-            self._current_track.name = self._current_track.uri
-            changed = True
+            if self._current_track.name == "":
+                self._current_track.name = self._current_track.uri
         artists = reader.get_artists(tags)
-        if artists != "" and self._current_track.artists != artists:
+        if len(artists) > 1 and self._current_track.artists != artists:
             self._current_track.artists = artists.split(",")
             changed = True
-        if not self._current_track.artists:
-            self._current_track.artists = self._current_track.album_artists
-            changed = True
+            if not self._current_track.artists:
+                self._current_track.artists = self._current_track.album_artists
         if changed:
             self.emit("current-changed")
 
@@ -364,7 +362,7 @@ class BinPlayer(BasePlayer):
         """
         self.emit("loading-changed", False)
         Logger.info("Player::_on_bus_error(): %s" % message.parse_error()[1])
-        if self.current_track.id >= 0:
+        if self.current_track.id is not None and self.current_track.id >= 0:
             if self.__codecs.is_missing_codec(message):
                 self.__codecs.install()
                 App().scanner.stop()
