@@ -10,12 +10,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk, GLib, Pango
 
 from time import time
 from gettext import gettext as _
 
-from lollypop.define import ViewType
+from lollypop.define import ViewType, App
 from lollypop.logger import Logger
 from lollypop.adaptive import AdaptiveView
 
@@ -52,6 +52,8 @@ class View(BaseView, Gtk.Grid):
         Gtk.Grid.__init__(self)
         self._view_type = view_type
         self.__overlayed = None
+        self.__scanner_signal_id = App().scanner.connect(
+            "album-updated", self._on_album_updated)
         self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_border_width(0)
         self.__new_ids = []
@@ -87,9 +89,9 @@ class View(BaseView, Gtk.Grid):
         self._scrolled.connect("leave-notify-event", self.__on_leave_notify)
         self._scrolled.show()
         self._viewport = Gtk.Viewport()
-        self._viewport.connect("destroy", self.__on_destroy)
         self._scrolled.add(self._viewport)
         self._viewport.show()
+        self.connect("destroy", self.__on_destroy)
         self.connect("map", self._on_map)
         self.connect("unmap", self._on_unmap)
 
@@ -106,6 +108,7 @@ class View(BaseView, Gtk.Grid):
         label_style = label.get_style_context()
         label_style.add_class("text-xx-large")
         label_style.add_class("dim-label")
+        label.set_ellipsize(Pango.EllipsizeMode.END)
         image = Gtk.Image.new_from_icon_name(self._empty_icon_name,
                                              Gtk.IconSize.DIALOG)
         image.get_style_context().add_class("dim-label")
@@ -196,6 +199,15 @@ class View(BaseView, Gtk.Grid):
         self._filter = self.__search_entry.get_text()
         self._box.invalidate_filter()
 
+    def _on_album_updated(self, scanner, album_id, added):
+        """
+            Handles changes in collection
+            @param scanner as CollectionScanner
+            @param album_id as int
+            @param added as bool
+        """
+        pass
+
     def _on_map(self, widget):
         pass
 
@@ -205,17 +217,6 @@ class View(BaseView, Gtk.Grid):
 #######################
 # PRIVATE             #
 #######################
-    def __update_widgets(self, widgets):
-        """
-            Update all widgets
-            @param widgets as BaseWidget
-        """
-        if widgets:
-            widget = widgets.pop(0)
-            widget.update_state()
-            widget.update_playing_indicator()
-            GLib.idle_add(self.__update_widgets, widgets)
-
     def __on_button_clicked(self, widget):
         """
             Hide widget, why GTK doesn"t do that?
@@ -252,11 +253,14 @@ class View(BaseView, Gtk.Grid):
            event.y >= allocation.height:
             self.disable_overlay()
 
-    def __on_destroy(self, viewport):
+    def __on_destroy(self, widget):
         """
-            Mark widget as destroyed
-            @param viewport as Gtk.Viewport
+            Clean up widget
+            @param widget as Gtk.Widget
         """
+        if self.__scanner_signal_id is not None:
+            App().scanner.disconnect(self.__scanner_signal_id)
+            self.__scanner_signal_id = None
         self._viewport = None
 
 
