@@ -69,6 +69,19 @@ class TracksView:
         except Exception as e:
             Logger.error("TrackView::set_playing_indicator(): %s" % e)
 
+    def update_duration(self, track_id):
+        """
+            Update track duration
+            @param track_id as int
+        """
+        try:
+            for disc in self.__discs:
+                number = disc.number
+                self._tracks_widget_left[number].update_duration(track_id)
+                self._tracks_widget_right[number].update_duration(track_id)
+        except Exception as e:
+            Logger.error("TrackView::update_duration(): %s" % e)
+
     def populate(self):
         """
             Populate tracks
@@ -234,12 +247,11 @@ class TracksView:
 #######################
 # PROTECTED           #
 #######################
-    def _on_album_updated(self, scanner, album_id, destroy):
+    def _on_album_updated(self, scanner, album_id):
         """
             On album modified, disable it
             @param scanner as CollectionScanner
             @param album id as int
-            @param destroy as bool
         """
         if self._album.id != album_id:
             return
@@ -476,23 +488,19 @@ class TracksView:
             @param widget as TracksWidget
             @param track as Track
         """
+        tracks = []
         for child in self.children:
+            tracks.append(child.track)
             child.set_state_flags(Gtk.StateFlags.NORMAL, True)
-        # Add to queue by default
-        if App().player.is_locked:
-            if track.id in App().player.queue:
-                App().player.remove_from_queue(track.id)
-            else:
-                App().player.append_to_queue(track.id)
+        # Do not update album list if in party or album already available
+        if not App().player.is_party and\
+                not App().player.track_in_playback(track):
+            album = self._album.clone(True)
+            album.set_tracks(tracks)
+            App().player.add_album(album)
+            App().player.load(album.get_track(track.id))
         else:
-            # Do not update album list if in party or album already available
-            if not App().player.is_party and\
-                    not App().player.track_in_playback(track):
-                album = self._album.clone(True)
-                App().player.add_album(album)
-                App().player.load(album.get_track(track.id))
-            else:
-                App().player.load(track)
+            App().player.load(track)
 
     def __on_insert_track(self, row, new_track_id, down):
         """
